@@ -8,6 +8,12 @@
 ##########################################################################
 from flask_babelex import gettext
 
+LOCK_LAYOUT_LEVEL = {
+    'PREVENT_DOCKING': 'docking',
+    'FULL': 'full',
+    'NONE': 'none'
+}
+
 
 def register_browser_preferences(self):
     self.show_system_objects = self.preference.register(
@@ -58,6 +64,21 @@ def register_browser_preferences(self):
         )
     )
 
+    self.lock_layout = self.preference.register(
+        'display', 'lock_layout',
+        gettext('Lock Layout'), 'radioModern', LOCK_LAYOUT_LEVEL['NONE'],
+        category_label=gettext('Display'), options=[
+            {'label': gettext('None'), 'value': LOCK_LAYOUT_LEVEL['NONE']},
+            {'label': gettext('Prevent Docking'),
+             'value': LOCK_LAYOUT_LEVEL['PREVENT_DOCKING']},
+            {'label': gettext('Full Lock'),
+             'value': LOCK_LAYOUT_LEVEL['FULL']},
+        ],
+        help_str=gettext(
+            'Lock the UI layout at different levels'
+        )
+    )
+
     self.table_row_count_threshold = self.preference.register(
         'properties', 'table_row_count_threshold',
         gettext("Count rows if estimated less than"), 'integer', 2000,
