@@ -7,6 +7,32 @@
 //
 //////////////////////////////////////////////////////////////
 
+{% macro A_MENU_ITEM(key, item) -%}
+{
+  name: "{{ item.name }}",
+  {% if item.module %}module: {{ item.module }},
+  {% endif %}{% if item.url %}url: "{{ item.url }}",
+  {% endif %}{% if item.target %}target: "{{ item.target }}",
+  {% endif %}{% if item.callback %}callback: "{{ item.callback }}",
+  {% endif %}{% if item.category %}category: "{{ item.category }}",
+  {% endif %}{% if item.icon %}icon: '{{ item.icon }}',
+  {% endif %}{% if item.data %}data: {{ item.data }},
+  {% endif %}label: '{{ item.label }}', applies: ['{{ key.lower() }}'],
+  priority: {{ item.priority }},
+  enable: '{{ item.enable }}',
+  {% if item.checked is defined %}checked: {% if item.checked %}true{% else %}false{% endif %},
+  {% endif %}
+  {% if item.menu_items %}menu_items: {{MENU_ITEMS(key, item.menu_items)}}
+  {% endif %}
+}
+{%- endmacro %}
+
+{% macro MENU_ITEMS(key, items) -%}
+[
+  {% for item in items %}{% if loop.index != 1 %}, {% endif %}
+    {{ A_MENU_ITEM(key, item) }}{% set hasMenus = True %}{% endfor %}
+]
+{%- endmacro %}
 
 define('pgadmin.browser.utils',
   ['sources/pgadmin'], function(pgAdmin) {
@@ -56,19 +82,7 @@ define('pgadmin.browser.utils',
       var self = this;
       if (this.counter.total == this.counter.loaded) {
         {% for key in ('File', 'Edit', 'Object' 'Tools', 'Management', 'Help') %}
-        obj.add_menus([{% for item in current_app.menu_items['%s_items' % key.lower()] %}{% if loop.index != 1 %}, {% endif %}{
-          name: "{{ item.name }}",
-          {% if item.module %}module: {{ item.module }},
-          {% endif %}{% if item.url %}url: "{{ item.url }}",
-          {% endif %}{% if item.target %}target: "{{ item.target }}",
-          {% endif %}{% if item.callback %}callback: "{{ item.callback }}",
-          {% endif %}{% if item.category %}category: "{{ item.category }}",
-          {% endif %}{% if item.icon %}icon: '{{ item.icon }}',
-          {% endif %}{% if item.data %}data: {{ item.data }},
-          {% endif %}label: '{{ item.label }}', applies: ['{{ key.lower() }}'],
-          priority: {{ item.priority }},
-          enable: '{{ item.enable }}'
-        }{% set hasMenus = True %}{% endfor %}]);
+        obj.add_menus({{ MENU_ITEMS(key, current_app.menu_items['%s_items' % key.lower()])}});
         {% endfor %}
         obj.create_menus();
       } else {
