@@ -18,6 +18,8 @@ from flask_babelex import gettext
 
 from config import PG_DEFAULT_DRIVER
 from pgadmin.utils.ajax import make_json_response, precondition_required
+from pgadmin.utils.exception import ConnectionLost, SSHTunnelConnectionLost,\
+    CryptKeyMissing
 
 
 def is_version_in_range(sversion, min_ver, max_ver):
@@ -289,18 +291,6 @@ class NodeView(with_metaclass(MethodViewType, View)):
                     methods=c['methods']
                 )
 
-    def module_js(self, **kwargs):
-        """
-        This property defines (if javascript) exists for this node.
-        Override this property for your own logic.
-        """
-        return flask.make_response(
-            flask.render_template(
-                "{0}/js/{0}.js".format(self.node_type)
-            ),
-            200, {'Content-Type': 'application/x-javascript'}
-        )
-
     def children(self, *args, **kwargs):
         """Build a list of treeview nodes from the child nodes."""
         children = []
@@ -333,9 +323,19 @@ class PGChildNodeView(NodeView):
         if 'did' in kwargs:
             did = kwargs['did']
 
-        conn = manager.connection(did=did)
-
-        if not conn.connected():
+        try:
+            conn = manager.connection(did=did)
+            if not conn.connected():
+                status, msg = conn.connect()
+                if not status:
+                    return precondition_required(
+                        gettext(
+                            "Connection to the server has been lost."
+                        )
+                    )
+        except (ConnectionLost, SSHTunnelConnectionLost, CryptKeyMissing):
+            raise
+        except Exception as e:
             return precondition_required(
                 gettext(
                     "Connection to the server has been lost."
