@@ -53,6 +53,8 @@ class PGUtilitiesBackupFeatureTest(BaseFeatureTest):
 
         self.wait = WebDriverWait(self.page.driver, 20)
 
+        test_gui_helper.close_bgprocess_popup(self)
+
     def runTest(self):
         self.page.toggle_open_server(self.server['name'])
         self.page.toggle_open_tree_item('Databases')
@@ -68,7 +70,6 @@ class PGUtilitiesBackupFeatureTest(BaseFeatureTest):
 
         self.wait.until(EC.element_to_be_clickable(
             (By.CSS_SELECTOR, ".file [name='file']"))).click()
-        # .input-group-append >button
         self.page.fill_input_by_field_name(
             "file", "test_backup", loose_focus=True)
 
@@ -77,11 +78,10 @@ class PGUtilitiesBackupFeatureTest(BaseFeatureTest):
 
         self.page.find_by_css_selector('.ajs-bg-bgprocess')
 
-        # status = self.page.find_by_css_selector(
-        #     ".pg-bg-status .bg-success-light .pg-bg-status-text").text
+        status = test_utils.get_watcher_dialogue_status(self)
 
-        status = self.page.find_by_css_selector(
-            ".pg-bg-status-text").text
+        if status != "Successfully completed.":
+            test_gui_helper.close_bgprocess_popup(self)
 
         self.assertEquals(status, "Successfully completed.")
 
@@ -130,8 +130,11 @@ class PGUtilitiesBackupFeatureTest(BaseFeatureTest):
 
         self.page.find_by_css_selector('.ajs-bg-bgprocess')
 
-        status = self.page.find_by_css_selector(
-            ".pg-bg-status-text").text
+        status = test_utils.get_watcher_dialogue_status(self)
+
+        if status != "Successfully completed.":
+            test_gui_helper.close_bgprocess_popup(self)
+
         self.assertEquals(status, "Successfully completed.")
 
         self.page.find_by_css_selector(
@@ -158,7 +161,6 @@ class PGUtilitiesBackupFeatureTest(BaseFeatureTest):
                 os.remove(backup_file)
 
     def after(self):
-        test_gui_helper.close_bgprocess_popup(self)
         self.page.remove_server(self.server)
         connection = test_utils.get_db_connection(
             self.server['db'],
